@@ -3,6 +3,7 @@
 import inspect
 import logging
 
+from .chain import Chain
 from .decorators import *
 from .ref import OpRef
 from .reflect import Meta
@@ -30,6 +31,8 @@ class Cluster(object, metaclass=Meta):
                     return attr(form)
 
                 setattr(instance, name, ctr.method(instance, name))
+            elif isinstance(attr, State):
+                setattr(instance, name, type(attr)(uri(cls) + f"/{name}"))
 
         return instance
 
@@ -41,6 +44,14 @@ class Cluster(object, metaclass=Meta):
         """Initialize this `Cluster`'s :class:~`chain.Chain`s."""
         pass
 
+    def _method(self, path):
+        subject = uri(self) + path
+        if subject.startswith("/state") and subject.path() != uri(self.__class__):
+            raise ValueError(
+                f"cannot call instance method {path} with an absolute path {uri(subject)}")
+
+        return subject
+
     def authorize(self, scope):
         """Raise an error if the current transaction has not been granted the given scope."""
 
