@@ -1,6 +1,6 @@
 """Reference types."""
 
-from .util import form_of, uri, URI, to_json
+from .util import *
 
 class Ref(object):
     """A reference to a :class:`State`."""
@@ -20,6 +20,10 @@ class After(Ref):
     def __json__(self):
         return {str(uri(self)): to_json([self.when, self.then])}
 
+    def __ns__(self, cxt):
+        deanonymize(self.when, cxt)
+        deanonymize(self.then, cxt)
+
 
 class Case(Ref):
     """A flow control operator used to branch execution conditionally."""
@@ -34,6 +38,11 @@ class Case(Ref):
     def __json__(self):
         return {str(uri(self)): to_json([self.cond, self.switch, self.case])}
 
+    def __ns__(self, cxt):
+        deanonymize(self.cond, cxt)
+        deanonymize(self.switch, cxt)
+        deanonymize(self.then, cxt)
+
 
 class If(Ref):
     """A flow control operator used to resolve a :class:`State` conditionally."""
@@ -48,6 +57,11 @@ class If(Ref):
     def __json__(self):
         return {str(uri(self)): to_json([self.cond, self.then, self.or_else])}
 
+    def __ns__(self, cxt):
+        deanonymize(self.cond, cxt)
+        deanonymize(self.then, cxt)
+        deanonymize(self.or_else, cxt)
+
 
 class OpRef(Ref):
     """A reference to an :class:`Op`."""
@@ -55,15 +69,21 @@ class OpRef(Ref):
     __uri__ = uri(Ref) + "/op"
 
     def __init__(self, subject, args):
-        if isinstance(subject, Ref):
-            self.subject = subject
-        else:
-            self.subject = uri(subject)
-
+        self.subject = subject
         self.args = args
 
     def __json__(self):
-        return {str(self.subject): to_json(self.args)}
+        if isinstance(self.subject, Ref):
+            subject = self.subject
+        else:
+            subject = uri(self.subject)
+
+        return {str(subject): to_json(self.args)}
+
+    def __ns__(self, cxt):
+        if isinstance(self.subject, MethodSubject):
+            deanonymize(self.subject, cxt)
+            deanonymize(self.args, cxt)
 
 
 class GetOpRef(OpRef):
@@ -72,10 +92,19 @@ class GetOpRef(OpRef):
     __uri__ = uri(OpRef) + "/get"
 
     def __init__(self, subject, key=None):
-        if str(uri(subject)).startswith("/state/scalar"):
-            OpRef.__init__(self, subject, key)
+        OpRef.__init__(self, subject, (key,))
+
+    def __json__(self):
+        if isinstance(self.subject, Ref):
+            subject = self.subject
         else:
-            OpRef.__init__(self, subject, (key,))
+            subject = uri(self.subject)
+
+        if str(uri(subject)).startswith("/state/scalar"):
+            (value,) = self.args
+            return {str(subject): to_json(value)}
+        else:
+            return {str(subject): to_json(self.args)}
 
 
 class PutOpRef(OpRef):
@@ -113,3 +142,28 @@ OpRef.Put = PutOpRef
 OpRef.Post = PostOpRef
 OpRef.Delete = DeleteOpRef
 
+
+class MethodSubject(object):
+    def __init__(self, subject, method_name):
+        self.__uri__ = None
+        self.subject = subject
+        self.method_name = method_name
+
+    def __ns__(self, cxt):
+        name = cxt.generate_name(self.subject.__class__.__name__)
+        self.__uri__ = URI(name).append(self.method_name)
+        setattr(cxt, name, self.subject)
+
+    def __json__(self):
+        if self.__uri__ is None:
+            raise ValueError(
+                f"cannot call method {self.method_name} on an anonymous subject {self.subject}")
+
+        return to_json(uri(self))
+
+    def __str__(self):
+        if self.__uri__ is None:
+            return str(uri(self.subject).append(self.method_name))
+        else:
+            return str(uri(self))
+
